import { CSSProperties, FC, ReactNode } from 'react';
import { TooltipAnchorProps } from '../Tooltip';
import { Size } from '../types/size';
export type ActionButtonVariant = 'primary' | 'danger' | 'success' | 'warning' | 'secondary' | 'inverse';
export type OnClickCallback = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
export interface ActionButtonProps extends TooltipAnchorProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Color of the button background.
     */
    bgColor?: CSSProperties['backgroundColor'];
    /**
    * Icon to be display.
    */
    children?: ReactNode;
    /**
     * Color of the icon displayed in the button.
     */
    color?: CSSProperties['color'];
    /**
     * Makes the button disabled.
     */
    disabled?: boolean;
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies the margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies the margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies the margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Click handler function.
     */
    onClick?: OnClickCallback;
    /**
     * Sets the size of the button.
     */
    size?: Size;
    /**
     * Indicates a small button. DEPRECATED
     */
    small?: boolean;
    /**
     * Can be used to set button type.
     */
    type?: 'submit' | 'reset' | 'button';
    /**
     * Defines the button variant.
     */
    variant?: ActionButtonVariant;
    /**
     * Specifies the id for testing.
     */
    'data-testid'?: string;
}
/**
  `ActionButton` communicate actions that users can take. They are typically placed throughout your UI, together with other `ActionButton` or alone.
  `ActionButton`s are similar to buttons, but their behavior and styling varies slightly.

  ### Import

  ```
  import ActionButton from '@impargo/components/ActionButton'
  ```
 */
export declare const ActionButton: FC<ActionButtonProps>;
export default ActionButton;
//# sourceMappingURL=index.d.ts.map