import { CSSProperties, FC } from 'react';
export type AlertVariant = 'primary' | 'info' | 'success' | 'danger' | 'warning';
export type OnClickCallback = (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => void;
export interface AlertProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Icon displayed on the left side alert text.
     */
    icon?: JSX.Element;
    /**
     * Defines the Alert variant.
     * @default 'primary'
     */
    variant?: AlertVariant;
    /**
     * Optional title to be displayed in the alert.
     */
    title?: string | JSX.Element;
    /**
     * Main message to display in the alert.
     */
    text?: string | JSX.Element;
    /**
     * Sets the main action that will be shown next to the alert message.
     */
    callToAction?: JSX.Element | JSX.Element[];
    /**
     * Sets the action that will be shown on the right side on the component, mostly used for a close button.
     */
    slotRight?: JSX.Element | JSX.Element[];
    /**
     * Specifies the white space property of the alert message.
     */
    whiteSpace?: CSSProperties['whiteSpace'];
    /**
     * Specifies a function when the entire component is clickable.
     */
    onClick?: OnClickCallback;
    /**
     * Specifies the margin top.
     */
    mt?: string;
    /**
     * Specifies the margin right.
     */
    mr?: string;
    /**
     * Specifies the margin bottom.
     */
    mb?: string;
    /**
     * Specifies the margin left.
     */
    ml?: string;
    /**
     * Specifies the padding top and bottom.
     */
    px?: string;
    /**
     * Specifies the padding right and left.
     */
    py?: string;
    /**
     * Specifies the width of the component. Use `min-content` to make the component shrink to the children.
     */
    width?: string;
    /**
     * Changes the `display` property from `flex` to `inline-flex`.
     * @default false
     */
    inline?: boolean;
    /**
     * Aligns the icon on the vertical axis. Possible values of the `align-self` property of a flex child.
     */
    alignIcon?: string;
    /**
     * Icon displayed on the left side alert text.
     */
    alignAction?: string;
}
/**
  `Alert`s are used to communicate feedback and to draw user attention to a specific topic. They can be used to communicate updates, top level app messages and feedback to users actions.

  ### Import

  ```
  import Alert from '@impargo/components/Alert'
  ```
 */
export declare const Alert: FC<AlertProps>;
export default Alert;
//# sourceMappingURL=index.d.ts.map