import { CSSProperties, FC, ReactNode } from 'react';
export type Overlap = 'rectangle' | 'circle' | 'inline';
export type Variant = 'primary' | 'secondary';
export type Shape = 'default' | 'dot';
export type Shadow = 'small' | 'medium' | 'large';
export interface BadgeProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Element(s) that will be wrapper in the badge component.
     */
    children?: ReactNode;
    /**
     * Wrapped shape the badge should overlap.
     * If `inline` is used the badge will be displayed as a stand alone element.
     * @default 'rectangle'
     */
    overlap?: Overlap;
    /**
     * Sets the color variant of the component.
     * @default 'primary'
     */
    variant?: Variant;
    /**
     * Sets the shape of the component.
     * Either a big badge with or without number and a small dot badge.
     * @default 'default'
     */
    shape?: Shape;
    /**
     * Controls whether the badge is hidden when `badgeCount` is zero.
     * Use alongside `badgeCount`.
     * @default false
     */
    showZero?: boolean;
    /**
     * Make the badge visible.
     */
    showBadge?: boolean;
    /**
      * Max count to show.
      * @default 99
      */
    max?: number;
    /**
     * The content rendered within the badge.
     * If the number `0` is meant to be displayed, use the `showZero` prop.
     * Has no effect if the `variant` `dot` is used.
     */
    badgeCount?: number;
    /**
     * Specifies the id for testing.
    */
    'data-testid'?: string;
    /**
     * Specifies the background color of the badge.
     */
    bgColor?: CSSProperties['backgroundColor'];
    /**
     * Specifies the text color of the badge.
     */
    color?: CSSProperties['color'];
    /**
     * Specifies the border color of the badge.
     */
    borderColor?: CSSProperties['borderColor'];
    /**
     * Specifies the box-shadow applied to the badge.
     */
    shadow?: Shadow;
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Specifies margin left and right.
     */
    mx?: string;
    /**
     * Specifies margin top and bottom.
     */
    my?: string;
    /**
    * Changes the `display` property from `flex` to `inline-flex`.
    * @default true
    */
    inline?: boolean;
}
/**
 * Badge generates a small badge to the top-right of its child(ren).
 * It can also be used as an inline element in `ListItem`s or in a table row. The badge is used to represent unread states.

  ### Import

  ```
  import Badge from '@impargo/components/Badge'
  ```

  ### Class names
  A class name is available to customize the badge. See more customization in [Custom](#custom).

  - `badge`
 */
export declare const Badge: FC<BadgeProps>;
export default Badge;
//# sourceMappingURL=index.d.ts.map