import { FC } from 'react';
type ConfirmationVariant = 'danger' | 'default';
interface ConfirmProps {
    className?: string;
    resolve: (flag: boolean) => void | null;
    onClose?: () => void | null;
    confirmationButtonText: string;
    declinationButtonText: string;
    confirmationMessage: string;
    variant?: ConfirmationVariant;
    icon: JSX.Element;
    explainationText?: string | JSX.Element;
    shouldCloseOnOverlayClick?: boolean;
}
export declare const Confirm: FC<ConfirmProps>;
/**
 * `ConfirmationModal` should be rendered before using the `confirm` function.
 * It can be renderer anywhere in the DOM.
 * Note: There should always only be one instance of the `ConfirmationModal`.
 */
export declare const ConfirmationModal: FC;
export interface ConfirmFunctionArgs {
    /**
     * The text that will be displayed in the confirmation button.
     */
    confirmationButtonText: string;
    /**
     * The text that will be displayed in the declination button.
     */
    declinationButtonText: string;
    /**
     * Contains the message that will be displayed in the confirmation modal.
     *  */
    confirmationMessage: string;
    /**
     * Styles the confirmation button.
     */
    variant?: ConfirmationVariant;
    /**
     * Specifies the icon beside the confirmation message.
     */
    icon: JSX.Element;
    /**
     * Should explain any side effects that might happen if the user confirms.
     */
    explainationText?: string | JSX.Element;
}
/**
 * The `ConfirmationModal` is a modal meant for requesting users a confirmation before cetain actions, such as delete an item or accept an invitation, take place.
 * The `ConfirmationModal` is open with a `confirm` function with passed arguamnts.
 * The `confirm` function has to be used with the `ConfirmationModal` component which has to be rendered anywhere in the DOM.
 * `ConfirmationModal` should be rendered before using the `confirm` function.
 * It can be renderer anywhere in the DOM.
 * Note: There should always only be one instance of the `ConfirmationModal`.

  ### Import

  ```
  import { ConfirmationModal } from '@impargo/components/ConfirmationModal'
  import confirm from '@impargo/components/ConfirmationModal'
  ```
 *
 * @param props Specifying the content of the modal.
 * @returns Boolean that indicated if the user has confirmed or declined the request.
 */
export declare const confirm: ({ confirmationMessage, confirmationButtonText, declinationButtonText, variant, explainationText, icon, }: ConfirmFunctionArgs) => Promise<boolean>;
export default confirm;
//# sourceMappingURL=index.d.ts.map