"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var jsx_runtime_1 = require("@emotion/react/jsx-runtime");
require("@testing-library/jest-dom");
var react_1 = require("@testing-library/react");
var _1 = require(".");
var resolve = jest.fn();
var onClose = jest.fn();
var renderConfirmModal = function (confirmationMessage, explainationText) {
    return (0, react_1.render)((0, jsx_runtime_1.jsx)(_1.Confirm, { confirmationMessage: confirmationMessage !== null && confirmationMessage !== void 0 ? confirmationMessage : '', explainationText: explainationText, declinationButtonText: 'No', confirmationButtonText: 'Yes', resolve: resolve, onClose: onClose, icon: (0, jsx_runtime_1.jsx)("span", { "data-testid": 'confirmation-icon' }) }));
};
var renderConfirmationModal = function () {
    return (0, react_1.render)((0, jsx_runtime_1.jsx)(_1.ConfirmationModal, {}));
};
describe('Confirm Modal', function () {
    it('should render properly', function () {
        var queryByTestId = renderConfirmModal().queryByTestId;
        expect(queryByTestId('message-text')).toBeInTheDocument();
        expect(queryByTestId('cancel-button')).toBeInTheDocument();
        expect(queryByTestId('confirm-button')).toBeInTheDocument();
    });
    it('should render the passed confirmation message and explaination message', function () {
        var confirmationMessage = 'Test message';
        var explainationMessage = 'explain';
        var queryByText = renderConfirmModal(confirmationMessage, explainationMessage).queryByText;
        expect(queryByText(confirmationMessage)).toBeInTheDocument();
    });
    it('should render with icon', function () {
        var queryByTestId = renderConfirmModal().queryByTestId;
        expect(queryByTestId('confirmation-icon')).toBeInTheDocument();
    });
    it('should call resolve and onClose when clicking any button', function () {
        var getByTestId = renderConfirmModal().getByTestId;
        react_1.fireEvent.click(getByTestId('confirm-button'));
        expect(resolve).toBeCalled();
        expect(onClose).toBeCalled();
        react_1.fireEvent.click(getByTestId('cancel-button'));
        expect(resolve).toBeCalled();
        expect(onClose).toBeCalled();
    });
});
describe('Confirm Container', function () {
    it('should render without crash', function () {
        renderConfirmationModal();
    });
    it('should throw error if there is more than one instance', function () {
        renderConfirmationModal();
        expect(function () {
            renderConfirmationModal();
        }).toThrow();
    });
});
