import { CSSProperties, FC, ReactNode } from 'react';
export interface ContainerProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
    * Elements displayed inside of the component.
    */
    children?: ReactNode;
    /**
     * Specifies the height of the container.
     */
    height?: CSSProperties['height'];
    /**
     * Specifies the width of the container.
     */
    width?: CSSProperties['width'];
    /**
     * Specifies the display property.
     */
    display?: CSSProperties['display'];
    /**
     * Specifies the position property.
     */
    position?: CSSProperties['position'];
    /**
     * Specifies the scrolling behavior.
     */
    overflow?: CSSProperties['overflow'];
    /**
     * Specifies the flex behavior.
     */
    flex?: CSSProperties['flex'];
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies the margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies the margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies the margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Specifies the margin right and left.
     */
    mx?: string;
    /**
     * Specifies the margin top and bottom.
     */
    my?: string;
    /**
     * Specifies the padding top.
     */
    pt?: CSSProperties['paddingTop'];
    /**
     * Specifies the padding right.
     */
    pr?: CSSProperties['paddingRight'];
    /**
     * Specifies the padding bottom.
     */
    pb?: CSSProperties['paddingBottom'];
    /**
     * Specifies the padding left.
     */
    pl?: CSSProperties['paddingLeft'];
    /**
     * Specifies the padding right and left.
     */
    px?: string;
    /**
     * Specifies the padding top and bottom.
     */
    py?: string;
}
/**
 * Thw `Container` component is used to contain different elements that display related content.

  ### Import

  ```
  import Container from '@impargo/components/Container'
  ```
 */
export declare const Container: FC<ContainerProps>;
export default Container;
//# sourceMappingURL=index.d.ts.map