import { FC } from 'react';
export interface DividerProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Changes the color of the divider.
     */
    variant?: 'default' | 'light' | 'dark' | 'inverse';
    /**
     * HTML element that should be rendered. Default `hr` is rendered.
     */
    el?: 'hr' | 'div' | 'span';
    /**
     * Divider orientation.
     * @default 'horizontal'.
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * Sets the width of the divider in horizontal orientation.
     * @default 100%
     */
    width?: string;
    /**
     * If true, a vertical divider will have the correct height when used in flex container.
     * By default, a vertical divider will have a calculated height of `0px` if it is the child of a flex container.
     * @default false
     */
    flexItem?: boolean;
    /**
     * Specifies the margin right and left. Accepts theme variables directly.
     * @default 0px
     */
    mx?: string;
    /**
     * Specifies the margin top and bottom. Accepts theme variables directly.
     * @default 0px
     */
    my?: string;
}
/**
 * Divider component is used to separate elements in the UI. Can be used on a horizontal layout or a vertical layout.

  ### Import

  ```
  import Divider from '@impargo/components/Divider'
  ```
 */
export declare const Divider: FC<DividerProps>;
export default Divider;
//# sourceMappingURL=index.d.ts.map