import { CSSProperties, ReactNode } from 'react';
import { DrawerPlace } from './styles';
export type { DrawerPlace } from './styles';
export interface DrawerProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Specifies the width of the drawer.
     * @default 288px
     */
    width?: CSSProperties['width'];
    /**
     * Overflow behaviour.
     * @default auto
     */
    overflow?: CSSProperties['overflow'];
    /**
     * Tells the drawer if it's shown or not.
     */
    isOpen: boolean;
    /**
     * Indicate if a click on the overlay outside the drawer should close the drawer. This prop is used in combination with `hasOverlay`.
     * @default false
     */
    shouldCloseOnOverlayClick?: boolean;
    /**
     * Boolean indicating if the drawer should restore focus to the element that had focus prior to its display.
     */
    shouldReturnFocusAfterClose?: boolean;
    /**
     * Specifies if an overlay should be displayed.
     * If the overlay is shown, clicking outside the drawer will close it if `shouldCloseOnOverlayClick` is set to true,
     * otherwise interaction with the background is possible if `hasOverlay` is set to false.
     * @default false
     */
    hasOverlay?: boolean;
    /**
     * Function that will be run when the drawer is requested to be closed (either by clicking on overlay or pressing ESC). Note: It is not called if isOpen is changed by other means.
     */
    onClose?: () => void;
    /**
     * Sets the position of the drawer - where the drawer is anchored.
     * @default bottom
     */
    place?: DrawerPlace;
    /**
     * Function that will be called to get the parent element that the modal will be attached to.
     */
    parentSelector?: () => HTMLElement;
    /**
    * Drawer content.
    */
    children?: ReactNode;
}
/**
 * Drawers are surfaces that contain supplementary content that are anchored to the right or to the bottom of the screen.

  ### Import

  ```
  import Drawer from '@impargo/components/Drawer'
  ```
 */
export declare const Drawer: import("@emotion/styled").StyledComponent<DrawerProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Drawer;
//# sourceMappingURL=index.d.ts.map