import { FC } from 'react';
export interface DropdownProps extends React.DetailedHTMLProps<React.HTMLAttributes<HTMLDivElement>, HTMLDivElement> {
    /**
     * Forces the dropdown menu to end at the right edge of its container. Deprecated since the component opens automatically based on it's location compared to the window.
     * @deprecated No longer needed because the menu is now `smartplaced` according to available space.
     * @default false
     */
    pullRight?: boolean;
    /**
     * A callback that is fired when the dropdown changes visibility.
     * Called with the open value.
     */
    onToggle?: (toggled: boolean) => void;
}
/**
 * The dropdown component displays a list of choices inside a floating surface.
 * The dropdown generally uses three components.
 *
 * - `Toggle` component to open and close the dropdown
 * - `Menu` component to wrap the different items
 * - `ListItem` components to display the actual items
 *
 * The `ListItem` component is configured to behave correctly as a `Dropdown` menu item,
 * simply pass an `onClick` handler to the `ListItem` instantiated under the `Menu` component,
 * and it will also handle closing the menu on click. Refer to [ListItem](https://impargo.github.io/impargo-design-system/?path=/docs/components-data-list-listitem--basic-usage) props for more info.

  ### Import

  ```
  import { Dropdown, Toggle, Menu } from '@impargo/components/Dropdown'
  import ListItem from '@impargo/components/List/ListItem'
  ```
 */
export declare const Dropdown: FC<DropdownProps>;
//# sourceMappingURL=Dropdown.d.ts.map