import { CSSProperties, FC, MouseEventHandler, ReactNode } from 'react';
import { TooltipAnchorProps } from '../Tooltip';
export type Gap = 'tiny' | 'xsmall' | 'small' | 'medium' | 'large' | 'xlarge' | 'xxlarge' | 'xxxlarge' | 'huge' | 'massive';
export interface FlexProps extends TooltipAnchorProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Specifies the id for testing.
    */
    'data-testid'?: string;
    /**
     * Specifies the flex direction property.
     */
    direction?: CSSProperties['flexDirection'];
    /**
     * Elements to display inside the component.
     */
    children: ReactNode;
    /**
     * Specifies the width of the component.
     */
    width?: CSSProperties['width'];
    /**
     * Specifies the height of the component.
     */
    height?: CSSProperties['height'];
    /**
     * Specifies if the children should wrap elements should wrap.
     */
    wrap?: boolean;
    /**
     * Sets the `flex` property.
     */
    flex?: CSSProperties['flex'];
    /**
     * Aligns the items along the main-axis (horizontally for row and vertically for column).
     */
    justify?: CSSProperties['justifyContent'];
    /**
     * Aligns the items inside of the flex container.
     */
    alignItems?: CSSProperties['alignItems'];
    /**
     * Aligns the component itself in the main axis. Works if the component is inside a flex container.
     */
    alignSelf?: CSSProperties['alignSelf'];
    /**
     * Aligns the items inside of the flex container.
     */
    alignContent?: CSSProperties['alignContent'];
    /**
     * Specifies the order of the component in case is used as a flex item.
     */
    order?: CSSProperties['order'];
    /**
     * Specifies spacing between the flex items. The `gap` prop is applied to a `Flex` component when the `item` prop is present.
     */
    gap?: Gap;
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies the margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies the margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies the margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Specifies the margin right and left.
     */
    mx?: string;
    /**
     * Specifies the margin top and bottom.
     */
    my?: string;
    /**
     * Specifies the padding top.
     */
    pt?: CSSProperties['paddingTop'];
    /**
     * Specifies the padding right.
     */
    pr?: CSSProperties['paddingRight'];
    /**
     * Specifies the padding bottom.
     */
    pb?: CSSProperties['paddingBottom'];
    /**
     * Specifies the padding left.
     */
    pl?: CSSProperties['paddingLeft'];
    /**
     * Specifies the padding right and left.
     */
    px?: string;
    /**
     * Specifies the padding top and bottom.
     */
    py?: string;
    /**
    * Specifies the on click handler when clicking on the element.
    */
    onClick?: MouseEventHandler;
}
/**
 * The `Flex` component can be used for flex layouts, specially when we want the same spacing between components (see `gap` prop).

  ### Import

  ```
  import Flex from '@impargo/components/Flex'
  ```
 */
export declare const Flex: FC<FlexProps>;
export default Flex;
//# sourceMappingURL=index.d.ts.map