import { FormikConfig, FormikValues } from 'formik';
import { ReactNode } from 'react';
export interface FormProps<FormValues extends FormikValues> extends FormikConfig<FormValues> {
    /**
     * Class name assigned to the component. Should be use sparingly.
     */
    className?: string;
    /**
     * Identifier for the form html element. Can be used for analytics purposes. Try not to use it for styling.
     */
    id?: string;
    /**
     * Allows form autocomplete if true.
     * @default false
     */
    autoComplete?: boolean;
    children?: ReactNode;
    /**
     * Set `data-testid` attribute on the form DOM node.
     */
    'data-testid'?: string;
}
type FormType = <T extends FormikValues>(props: FormProps<T>) => React.ReactElement<FormProps<T>>;
/**
 * Form is a logical wrapper that uses with formik that is used in order to encapsulate input fields.
 * It should be used with Formik's `Field` component or our own Formik input components (e.g. `FormikNumberInput`).
 *
 * Form accept accepts anything props you would pass to `Formik` component.
 * See [formik reference](https://formik.org/docs/api/formik#formik-render-methods-and-props) for details.
 */
export declare const Form: FormType;
export default Form;
//# sourceMappingURL=index.d.ts.map