import { CSSProperties } from 'react';
export type Variant = 'default' | 'primary' | 'accent' | 'danger' | 'success' | 'warning' | 'secondary';
export type Size = 'xs' | 's' | 'm' | 'l' | 'xl';
export interface IconProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Letter to display instead of the icon. If icon and text are both passed as props, only the text prop will be displayed.
     */
    text?: string | JSX.Element;
    /**
     * Icon to display in the component.
     * The icon library used is the FontAwesome icon library along with the `FontAwesomeIcon` component for React.
     */
    icon?: JSX.Element;
    /**
     * Changes the variant of the icon depending on the use case.
     * @default 'default'
     */
    variant?: Variant;
    /**
     * Changes the container size of the icon component. For changing the size of the icon, use the prop size on the `FontAwesomeIcon` component.
     * @default 's'
     */
    size?: Size;
    /**
     * Specifies the background color of the icon.
     */
    bgColor?: CSSProperties['backgroundColor'];
    /**
     * Specifies the text color of the icon.
     */
    color?: CSSProperties['color'];
    /**
     * Specifies border color. `border-width` and `border-style` are set to `1px` and `solid` respectively.
     */
    borderColor?: CSSProperties['borderColor'];
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies the margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies the margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies the margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Specifies the margin left and right.
     */
    mx?: string;
    /**
     * Specifies the margin top and bottom.
     */
    my?: string;
    'data-testid'?: string;
}
/**
 * `Icon` component can be used to display different icons either with font-awesome icons or just plain text. Icons can be used to give extra context to the user realated to an action or specific information.

  ### Import

  ```
  import Icon from '@impargo/components/Icon'
  ```
 */
export declare const Icon: import("@emotion/styled").StyledComponent<IconProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Icon;
//# sourceMappingURL=index.d.ts.map