import 'react-datepicker/dist/react-datepicker.css';
import { FC } from 'react';
import { DatePickerProps } from 'react-datepicker';
import { InputContainerProps } from '../InputContainer';
import { DateInputValueType } from './helpers';
export type DateInputProps = Omit<InputContainerProps, 'suffix' | 'slotLeft'> & Omit<DatePickerProps, 'selected' | 'startDate' | 'endDate' | 'value' | 'onChange' | 'selectsRange' | 'selectsMultiple' | 'showMonthYearDropdown'> & {
    /**
     * More specific type of date input.
     * @default date
     */
    type?: 'date' | 'datetime' | 'daterange';
    /**
     * Current value of the input.
     * Of composite type `DateInputValueType` which depends on `type`.
     */
    value?: DateInputValueType | null;
    /**
     * `onChange` callback called with value of type `DateInputValueType` which depends on `type`.
     */
    onChange: (value: DateInputValueType) => void;
    /**
     * This has to be a date-fns locale
     */
    locale?: Locale;
    /**
     * Converts the date values selected by the datepicker to use UTC time
     */
    normalizeToUTC?: boolean;
};
/**
  ### Import using Formik

  ```
  import { FormikDateInput } from '@impargo/components/Input/DateInput'
  ```

  ### Import

  ```
  import { DateInput } from '@impargo/components/Input/DateInput'
  ```
 */
export declare const DateInput: FC<DateInputProps>;
//# sourceMappingURL=DateInput.d.ts.map