"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseDateValue = exports.denormalizeDateValue = exports.normalizeDateValue = exports.denormalizeDateFromUTC = exports.normalizeDateToUTC = exports.isDate = exports.formatDate = exports.DATE_TIME_FORMAT = exports.TIME_FORMAT = exports.DATE_FORMAT = void 0;
var add_1 = __importDefault(require("date-fns/add"));
var format_1 = __importDefault(require("date-fns/format"));
exports.DATE_FORMAT = 'P';
exports.TIME_FORMAT = 'HH:mm';
exports.DATE_TIME_FORMAT = 'P HH:mm';
var formatDate = function (date, locale) {
    return date ? (0, format_1.default)(date, exports.DATE_FORMAT, { locale: locale }) : '';
};
exports.formatDate = formatDate;
var isDate = function (value) {
    return value instanceof Date;
};
exports.isDate = isDate;
/**
 * Takes local time and converts it to the same UTC time.
 */
var normalizeDateToUTC = function (value) {
    return (0, add_1.default)(value, { minutes: -value.getTimezoneOffset() });
};
exports.normalizeDateToUTC = normalizeDateToUTC;
/**
 * Takes a UTC time and converts it to the same local time.
 */
var denormalizeDateFromUTC = function (value) {
    return (0, add_1.default)(value, { minutes: value.getTimezoneOffset() });
};
exports.denormalizeDateFromUTC = denormalizeDateFromUTC;
var normalizeDateValue = function (value) {
    if ((0, exports.isDate)(value)) {
        return (0, exports.normalizeDateToUTC)(value);
    }
    else if ((value === null || value === void 0 ? void 0 : value.from) || (value === null || value === void 0 ? void 0 : value.to)) {
        return {
            from: (value === null || value === void 0 ? void 0 : value.from) && (0, exports.normalizeDateToUTC)(value.from),
            to: (value === null || value === void 0 ? void 0 : value.to) && (0, exports.normalizeDateToUTC)(value.to),
        };
    }
    else {
        return null;
    }
};
exports.normalizeDateValue = normalizeDateValue;
var denormalizeDateValue = function (value) {
    if ((0, exports.isDate)(value)) {
        return (0, exports.denormalizeDateFromUTC)(value);
    }
    else if ((value === null || value === void 0 ? void 0 : value.from) || (value === null || value === void 0 ? void 0 : value.to)) {
        return {
            from: (value === null || value === void 0 ? void 0 : value.from) && (0, exports.denormalizeDateFromUTC)(value.from),
            to: (value === null || value === void 0 ? void 0 : value.to) && (0, exports.denormalizeDateFromUTC)(value.to),
        };
    }
    else {
        return null;
    }
};
exports.denormalizeDateValue = denormalizeDateValue;
var parseDateValue = function (v) {
    if (v instanceof Date) {
        // date / datetime case
        return v;
    }
    else if (!v || (!v[0] && !v[1])) {
        return null;
    }
    else {
        // daterange case
        return { from: v[0], to: v[1] };
    }
};
exports.parseDateValue = parseDateValue;
