import { TooltipProps } from '@impargo/components/Tooltip';
import { FC, ReactNode } from 'react';
import { InputContainerStyleProps } from './styles';
export interface InputContainerProps extends InputContainerStyleProps {
    /**
     * Text shown on the left of the input
     */
    label?: ReactNode;
    /**
     * Optional icon to be shown to the right of the input
     */
    slotRight?: ReactNode;
    /**
     * Optional icon to be shown to the left of the input
     */
    slotLeft?: JSX.Element;
    /**
     * Used with checkbox and switch inputs only.
     * Renders the label to the right of the checkbox/switch.
     * @default false
     */
    reversed?: boolean;
    /**
     * Name of the input in form.
     */
    name?: string;
    /**
     * Shows the info icon and contains the message shown on the info icon tooltip.
     */
    infoText?: string;
    /**
     * Designates the info text tooltip placement.
     * @default bottom
     */
    tooltipPlace?: TooltipProps['place'];
    /**
     * Renders a string to the right of the input box.
     * Will override the `slotRight` prop.
     */
    suffix?: string;
    /**
     * Indicates wether the input has been touched.
     * Influences validation and wether an error is shown.
     */
    touched?: boolean;
    /**
     * Error text that should inform the user of a wrong input.
     */
    error?: string;
    /**
     * Decorator to be place below the input element to help the user fill out the field correctly.
     */
    helperText?: ReactNode;
    /**
     * Sets optional text next to the label.
     * Functions as a decorator to tell the user that the field is optional.
     */
    optionalDecorator?: string;
    /**
     * Decorator (Asterix*) to tell the user that the field is required.
     * @default false
     */
    requiredDecorator?: boolean;
    /**
     * Set's this field to be required.
     * Triggers native browser validation on submit of the form.
     * @default false
     * @deprecated use validate method and custom validation logic instead
     */
    required?: boolean;
    /**
     * Decorator to be place on the left side of the input label. Generally used for indicators (e.g. `TierIndicator`).
     */
    leftDecorator?: ReactNode;
    /**
     * Decorator to be place on the right side of the input label.
     */
    rightDecorator?: ReactNode;
    /**
     * This allows errors to be shown even before the input is touched or changed.
     */
    forceShowError?: boolean;
    /**
     * Class name assigned to the component. Should be use sparingly.
     */
    className?: string;
    'data-testid'?: string;
    /**
   *  Specifies if the text color is secondary.
   */
    secondaryLabel?: boolean;
}
export declare const InputContainer: FC<React.PropsWithChildren<InputContainerProps>>;
//# sourceMappingURL=InputContainer.d.ts.map