import { SerializedStyles } from '@emotion/react';
import { CSSProperties, ReactNode } from 'react';
import { ThemeType } from '../../Themes';
export interface InputContainerStyleProps {
    /**
     * Disables the input and applies disabled styles.
     * @default false
     */
    disabled?: boolean;
    /**
     * Defines the type of the input.
     * Possible values are [date, datetime, checkbox, select, creatableselect, multiselect, creatablemultiselect, number,daterange, timerange, textarea, range] as well as any of the default input types.
     * @default text
     */
    type?: string;
    /**
     * Use secondary styling for the input label.
     */
    secondaryLabel?: boolean;
    /**
     * Sets label and input layout in a vertical manner.
     * @default false
     */
    isVertical?: boolean;
    /**
     * Sets label and input layout in a vertical manner only on mobile (479px).
     * @default false
     */
    isVerticalMobile?: boolean;
    /**
     * Decorator to be place on the right side of the input label.
     */
    rightDecorator?: ReactNode;
    /**
     * Used with checkbox inputs.
     * Renders the label to the right of the checkbox.
     * @default false
     */
    reversed?: boolean;
    /**
     * Changes the ratio of label width to input width to 1:3.
     * @default false
     */
    smallLabel?: boolean;
    /**
     * Used to make the whole input larger (usually wider).
     * @default false
     */
    large?: boolean;
    /**
     * Specifies the variant of the input.
     * Primary inputs have higher contrast backgrounds than secondary.
     */
    variant?: 'primary' | 'secondary';
    /**
     * Forces label to be aligned to the right
     * @default false
     */
    right?: boolean;
    flex?: CSSProperties['flex'];
    textAlign?: CSSProperties['textAlign'];
    label?: ReactNode;
    /**
     * Controls whether the default input margins when inside a form are applied.
     * @default true
     */
    enableFormMargins?: boolean;
}
export declare const getStyle: (theme: ThemeType, { disabled, type, secondaryLabel, isVertical, rightDecorator, reversed, isVerticalMobile, smallLabel, flex, large, textAlign, variant, right, label, enableFormMargins, }: InputContainerStyleProps) => SerializedStyles;
//# sourceMappingURL=styles.d.ts.map