import { FC } from 'react';
import { InputContainerProps } from '../InputContainer';
export type NumberInputProps = Omit<InputContainerProps, 'type'> & Omit<React.InputHTMLAttributes<HTMLInputElement>, 'type' | 'value'> & {
    /**
     * Current value of the input.
     */
    value: number | null;
    /**
     * Number of decimal fractions to which the value if rounded to.
     */
    fractionDigits?: number;
    /**
     * Additional `onChange` handler that is called with the value.
     * If specified rounding and [min, max] bounds are applied to the value beforehand.
     */
    onValueChange?: (number: number) => void;
    /**
     * Lower bound for the value.
     */
    min?: number;
    /**
     * Upper bound for the value.
     */
    max?: number;
};
/**
 * Number input component with built in support for:
 *
 * - Rounding to `fractionDigits`
 * - Lower and upper bounds [`min`, `max`]

  ### Import using Formik

  ```
  import { FormikNumberInput } from '@impargo/components/Input/NumberInput'
  ```

  ### Import

  ```
  import { NumberInput } from '@impargo/components/Input/NumberInput'
  ```
 */
export declare const NumberInput: FC<NumberInputProps>;
//# sourceMappingURL=NumberInput.d.ts.map