import { ReactElement } from 'react';
import { AsyncProps } from 'react-select/async';
import type { SelectOptionType, SelectProps } from './Select';
export type { SelectOptionType, SelectRef } from './Select';
export interface AsyncSelectProps<OptionType extends {}> extends Omit<SelectProps<OptionType, false>, 'value' | 'options' | 'onChange'>, AsyncProps<OptionType> {
    value: OptionType | null;
    onChange: (value: OptionType | null) => void;
}
/**
  ### When to use
  Use AsyncSelect when you want to search results via an async API, for example when fetching results from the backend or a third party.

  The prop `loadOptions` should be a function that takes the search value and returns a promise of an array of options.

  ### Import using Formik

  ```
  import { FormikAsyncSelect } from '@impargo/components/Input/Select/AsyncSelect'
  ```

  ### Import

  ```
  import { AsyncSelect } from '@impargo/components/Input/Select/AsyncSelect'
  ```
 */
export declare function AsyncSelect<OptionType extends SelectOptionType>({ value, dropup, components, innerRef, onChange, ...props }: AsyncSelectProps<OptionType>): ReactElement;
//# sourceMappingURL=AsyncSelect.d.ts.map