import { MutableRefObject, ReactElement, ReactNode } from 'react';
import { GroupedOptionsType, NamedProps, SelectComponentsConfig, StylesConfig } from 'react-select';
import { CreatableProps } from 'react-select/creatable';
import { InputContainerProps } from '../InputContainer';
/**
 * Deprecated. Import from '@impargo/components/Input/Select/Components' instead.
 */
export declare const Components: import("react-select/src/components").Components;
export type SelectOptionType = {
    value: string;
    label: ReactNode;
};
export type SelectValueType = string | string[] | null;
type ReactSelectBaseProps<OptionType extends {}, IsMulti extends boolean> = Omit<NamedProps<OptionType, IsMulti>, 'isMulti' | 'closeMenuOnSelect' | 'isDisabled' | 'value' | 'components' | 'classNamePrefix' | 'className' | 'onChange' | 'options' | 'styles'>;
type ReactSelectProps<OptionType extends {}, IsMulti extends boolean> = ReactSelectBaseProps<OptionType, IsMulti> & CreatableProps<OptionType, IsMulti>;
export type SelectRef = {
    focus: () => void;
    blur: () => void;
};
export type SelectProps<OptionType extends {}, IsMulti extends boolean> = Omit<InputContainerProps, 'type' | 'slotRight' | 'suffix'> & ReactSelectProps<OptionType, IsMulti> & {
    dropup?: boolean;
    /**
     * Specifies wether multiple values can be selected.
     * @default false
     */
    multi?: IsMulti;
    creatable?: boolean;
    options: GroupedOptionsType<OptionType> | OptionType[];
    value: SelectValueType;
    /**
     * Only for multiselects. Set this for example to null when using it for filtering logic.
     */
    defaultEmptyValue?: [] | null;
    onChange: (value: SelectValueType) => void;
    innerRef?: MutableRefObject<SelectRef | null>;
    components?: SelectComponentsConfig<OptionType, IsMulti>;
    slotLeft?: JSX.Element | null;
    styles?: StylesConfig<OptionType, IsMulti>;
    onMissingOption?: (value: string) => OptionType;
};
/**
  ### When to use
  Use Select when you want the users to choose from a predefined list of options.
  The prop `options` should be an array of options in the shape `[{ label: string, value: string }]`.

  Refer to AsyncSelect if you don't have a predefined list of options, and instead want to fetch the options via an API.

  ### Import using Formik

  ```
  import { FormikSelect } from '@impargo/components/Input/Select'
  ```

  ### Import

  ```
  import { Select } from '@impargo/components/Input/Select'
  ```
 */
export declare function Select<OptionType extends SelectOptionType, IsMulti extends boolean = false>({ onChange, value, dropup, options, defaultEmptyValue, multi, creatable, components, innerRef, styles, onMissingOption, ...props }: SelectProps<OptionType, IsMulti>): ReactElement;
export {};
//# sourceMappingURL=Select.d.ts.map