import { SliderProps } from '@material-ui/core/Slider';
import { FC } from 'react';
import { InputContainerProps } from '../InputContainer';
export type SliderInputProps = Omit<InputContainerProps, 'type' | 'helperText' | 'slotLeft' | 'suffix'> & Omit<SliderProps, 'onChange' | 'onChangeCommitted'> & {
    /**
     * Used to set the label above slider inputs.
     * It's called with the current slider value.
     * If not passed, the slider value will be used instead.
     */
    sliderLabel?: (value: number | number[]) => string;
    /**
     * `onChange` handler called with the new value once the user has stopped sliding.
     */
    onChangeCommitted?: (value: number | number[]) => void;
};
/**
 * Slider input, uses Material slider behind the scene.
 *
 * For performance reasons, this component can't be used as a fully controlled input.
 * The only way to tap into its value is by using the onChangeCommitted handler,
 * which only triggers after the user stops sliding. Passing a changing value
 * to the input will work though, to enable the slider to be used in forms

  ### Import using Formik

  ```
  import { FormikSliderInput } from '@impargo/components/Input/SliderInput'
  ```

  ### Import

  ```
  import { SliderInput } from '@impargo/components/Input/SliderInput'
  ```
 */
export declare const SliderInput: FC<SliderInputProps>;
//# sourceMappingURL=SliderInput.d.ts.map