import { FC, FocusEventHandler } from 'react';
import { InputContainerProps } from '../../InputContainer';
export interface TimeInputValueType {
    from: string;
    to: string;
}
export interface TimeInputProps extends Omit<InputContainerProps, 'type' | 'slotLeft' | 'suffix'> {
    /**
     * Value of the input component (minutes).
     */
    value: number;
    /**
     * `onChange` callback with the minutes as a number.
     */
    onChange: (minutes: number) => void;
    /**
     * `onBlur` callback can be used to listen to onBlur event after the `onChange` callback has been called.
     */
    onBlur?: FocusEventHandler<HTMLInputElement>;
    /**
     * Use a slider to choose the time window.
     * Can be used also in combination with `textInput`.
     * @default false
     */
    sliderInput?: boolean;
    /**
     * Close the modal when clicking outside.
     * @default true
     */
    closeOnClickOutside?: boolean;
    /**
     * Title of the displayed modal.
     * @default 'Time'
     */
    modalTitle?: string;
    /**
     * If the slider is enabled, then the amount of time (in minutes) between each slider tick.
     * @default 15
     */
    sliderStep?: number;
    /**
     * Maximum allowed set time in minutes.
     * @default 960 Default value is 16 hours.
     */
    max?: number;
    disabled?: boolean;
    minWidth?: string;
}
/**
  ### Import using Formik

  ```
  import { FormikTimeInput } from '@impargo/components/Input/TimeInput'
  ```

  ### Import

  ```
  import { TimeInput } from '@impargo/components/Input/TimeInput'
  ```
 */
export declare const TimeInput: FC<TimeInputProps>;
//# sourceMappingURL=TimeInput.d.ts.map