import { FC, FocusEventHandler } from 'react';
import { InputContainerProps } from '../../InputContainer';
export interface TimerangeValueType {
    from: string;
    to: string;
}
export interface TimerangeInputProps extends Omit<InputContainerProps, 'type' | 'slotLeft' | 'suffix'> {
    /**
     * Value of the input component (of type `TimerangeValueType`).
     */
    value: TimerangeValueType;
    /**
     * `onChange` callback with one argument `value: TimerangeValueType`.
     */
    onChange: (value: TimerangeValueType) => void;
    /**
     * `onBlur` callback can be used to listen to onBlur event after the `onChange` callback has been called.
     */
    onBlur?: FocusEventHandler<HTMLInputElement>;
    /**
     * Use a text input to choose the time window.
     * Can be used also in combination with `sliderInput`.
     * @default true
     */
    textInput?: boolean;
    /**
     * Use a slider to choose the time window.
     * Can be used also in combination with `textInput`.
     * @default false
     */
    sliderInput?: boolean;
    /**
     * Close the modal when clicking outside.
     * @default true
     */
    closeOnClickOutside?: boolean;
    /**
     * Title of the displayed modal.
     * @default 'Time window'
     */
    timeWindowTitle?: string;
    /**
     * Start of the time window label.
     * @default 'From: '
     */
    openTimeLabel?: string;
    /**
     * End of the time window label.
     * @default 'To: '
     */
    closeTimeLabel?: string;
    disabled?: boolean;
    minWidth?: string;
}
/**
  ### Import using Formik

  ```
  import { FormikTimerangeInput } from '@impargo/components/Input/TimerangeInput'
  ```

  ### Import

  ```
  import { TimerangeInput } from '@impargo/components/Input/TimerangeInput'
  ```
 */
export declare const TimerangeInput: FC<TimerangeInputProps>;
//# sourceMappingURL=TimerangeInput.d.ts.map