"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHandleInputCursor = exports.select = exports.changeTime = exports.isValidTime = exports.minutesToFormattedTime = exports.minutesToHoursAndMinutes = exports.formattedTimeToMinutes = void 0;
var date_fns_1 = require("date-fns");
var react_1 = require("react");
var incrementTime = function (timeInMinutes, changeHours, max) {
    timeInMinutes = timeInMinutes + (changeHours ? 60 : 1);
    return Math.min(max !== null && max !== void 0 ? max : 1439, timeInMinutes);
};
var decrementTime = function (timeInMinutes, changeHours) {
    timeInMinutes = timeInMinutes - (changeHours ? 60 : 1);
    return Math.max(0, timeInMinutes);
};
var formattedTimeToMinutes = function (value) {
    if (value) {
        var _a = (value.split && value.split(':')) || ['0', '0'], hours = _a[0], minutes = _a[1];
        return (Number.parseInt(hours) * 60 + Number.parseInt(minutes));
    }
    return 0;
};
exports.formattedTimeToMinutes = formattedTimeToMinutes;
var minutesToHoursAndMinutes = function (value) {
    return {
        h: Math.floor(value / 60),
        m: value % 60,
    };
};
exports.minutesToHoursAndMinutes = minutesToHoursAndMinutes;
var minutesToFormattedTime = function (value) {
    var _a = (0, exports.minutesToHoursAndMinutes)(value), h = _a.h, m = _a.m;
    var hs = (h.toString().length < 2) ? ('0' + h) : h;
    var ms = (m.toString().length < 2) ? ('0' + m) : m;
    return "".concat(hs, ":").concat(ms);
};
exports.minutesToFormattedTime = minutesToFormattedTime;
var isValidTime = function (str) {
    return (str === null || str === void 0 ? void 0 : str.length) === 5 && (0, date_fns_1.isMatch)(str, 'HH:mm');
};
exports.isValidTime = isValidTime;
var changeTime = function (timeInMinutes, changeHours, event, max) {
    if (event.key === 'ArrowUp') {
        timeInMinutes = incrementTime(timeInMinutes, changeHours, max);
    }
    else if (event.key === 'ArrowDown') {
        timeInMinutes = decrementTime(timeInMinutes, changeHours);
    }
    event.preventDefault();
    return timeInMinutes;
};
exports.changeTime = changeTime;
var getSelectionStart = function (currentSelectionStart) {
    if (currentSelectionStart < 3)
        return 0;
    else if (currentSelectionStart >= 3 && currentSelectionStart < 6)
        return 3;
    else if (currentSelectionStart >= 6 && currentSelectionStart < 11)
        return 8;
    return 11;
};
var select = function (e, setSelectionStart, validTime) {
    var selectionStart = getSelectionStart(e.currentTarget.selectionStart);
    setSelectionStart(selectionStart);
    validTime
        ? e.currentTarget.setSelectionRange(selectionStart, selectionStart + 2)
        : e.currentTarget.setSelectionRange(selectionStart + 1, selectionStart + 1);
};
exports.select = select;
var useHandleInputCursor = function (input, selectionStart, textValue) {
    var _a = (0, react_1.useState)(false), resetCursor = _a[0], setResetCursor = _a[1];
    (0, react_1.useEffect)(function () {
        input === null || input === void 0 ? void 0 : input.addEventListener('select', function () { return setResetCursor(false); });
        input === null || input === void 0 ? void 0 : input.addEventListener('keydown', function (e) {
            if (e.key === 'ArrowUp' || e.key === 'ArrowDown')
                setResetCursor(true);
        });
    }, [input]);
    (0, react_1.useEffect)(function () {
        if (resetCursor)
            input === null || input === void 0 ? void 0 : input.setSelectionRange(selectionStart, selectionStart + 2);
    }, [textValue]);
};
exports.useHandleInputCursor = useHandleInputCursor;
