/// <reference types="react" />
import { OnClickCallback } from '../Button';
export interface ModalHeaderProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Icon to diplay in the top-left corner of the modal.
     */
    icon?: string | JSX.Element;
    /**
     * Title of the modal.
     */
    title?: string | JSX.Element;
    /**
     * Handler called when the close button is pressed.
     */
    onClose?: OnClickCallback;
    /**
     * Text to be shown as the close button in the full screen modal. Alternative to `closeIcon`.
     */
    closeText?: string;
    /**
     * Icon to be displayed as close button. Alternative to `closeText`.
     */
    closeIcon?: string | JSX.Element;
    /**
     * Additional text displayed with the title.
     */
    helperText?: string | JSX.Element;
    /**
     * Specifies if the modal header will have styles for the full screen modal.
     * Tells the modal header to show the close text instead of the close icon.
     * @default false
     */
    fullScreen?: boolean;
}
/**
 * Layout component used for the header of modals. Containing the  title and possibly a close button.

  ### Import

  ```
  import ModalHeader from '@impargo/components/Modal/ModalHeader'
  ```
 */
export declare const ModalHeader: import("@emotion/styled").StyledComponent<ModalHeaderProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default ModalHeader;
//# sourceMappingURL=ModalHeader.d.ts.map