import { CSSProperties } from '@material-ui/core/styles/withStyles';
import { ReactNode } from 'react';
export interface ModalProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Tells the modal if it's shown or not.
     */
    isOpen: boolean;
    /**
     * Indicate if the overlay should close the modal.
     * @default true
     */
    shouldCloseOnOverlayClick?: boolean;
    /**
     * Function that will be run when the modal is requested to be closed (either by clicking on overlay or pressing ESC). Note: It is not called if isOpen is changed by other means.
     */
    onClose?: () => void;
    /**
     * Specifies if the modal will cover the full screen of the browser.
     * @default false
     */
    fullScreen?: boolean;
    /**
     * Indicates the overflow behaviour of the modal.
     * @default auto
     */
    overflow?: CSSProperties['overflow'];
    /**
     * Indicates if the modal should be of size small.
     * @default false
     */
    small?: boolean;
    /**
     * Indicates if the modal should be of size medium.
     */
    medium?: boolean;
    /**
    * Drawer content.
    */
    children?: ReactNode;
}
/**
 * Flexible modal component with different sizes `small` `medium` `large` or `fullscreen`.
 * Can be used in combination with `ModalHeader`, `ModalFooter` or `ModalBody` depending on the use-case.
 * The modals are used when the user is required to interact with the application without the need to open a different page or view and interrupting the users workflow.

  ### Import

  ```
  import Modal from '@impargo/components/Modal'
  import ModalHeader from '@impargo/components/Modal/ModalHeader'
  import ModalBody from '@impargo/components/Modal/ModalBody'
  ```
 */
export declare const Modal: import("@emotion/styled").StyledComponent<ModalProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Modal;
//# sourceMappingURL=index.d.ts.map