/// <reference types="react" />
import { CSSProperties } from '@material-ui/core/styles/withStyles';
export interface PageHeaderProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Title to be displayed.
     */
    title?: string;
    /**
     * An element to be displayed right next to the title, for example to highlight new features.
     */
    highlight?: JSX.Element;
    /**
     * Element to be displayed instead of the title whenever the page changes it's content based on the same context,
     * for example displaying order coming form a notification.
     */
    backButton?: JSX.Element;
    /**
     * Elements displayed to the right of the title. Meant for actions related to the page.
     */
    slotRight?: JSX.Element;
    /**
     * Designates the tooltip placement for the infoText.
     * @default bottom
     */
    tooltipPlace?: 'top' | 'right' | 'bottom' | 'left';
    /**
     * Info text displayed right next to the title as a tooltip.
     * Might contain extra info regarding the current page.
     */
    infoText?: string;
    /**
     * Specifies if the component has a bottom border.
     * @default true
     */
    hasBorder?: boolean;
    /**
     * Specifies the `grid-area` property.
     * This prop only works when using CSS Grid.
     */
    gridArea?: CSSProperties['gridArea'];
}
/**
 * The `PageHeader` component is used as the header of a page. It displays a title and different actions depending on the purpose of the page.

  ### Import

  ```
  import PageHeader from '@impargo/components/PageHeader'
  ```
 */
export declare const PageHeader: import("@emotion/styled").StyledComponent<PageHeaderProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default PageHeader;
//# sourceMappingURL=index.d.ts.map