import { CSSProperties, FC, MouseEventHandler } from 'react';
import { SheetVariant } from '.';
export interface SheetHeaderProps {
    /**
    * Class name assigned to the component. Should be use sparingly.
    */
    className?: string;
    /**
    * Text displayed as the title of the `Sheet`.
    */
    title: string | JSX.Element;
    /**
     * Text displayed below the title. Used to add additional context.
     */
    subtitle?: string | JSX.Element;
    /**
    * Specifies the variant of the component.
    */
    variant?: SheetVariant;
    /**
    * Specifies if the component has a border bottom or not.
    * @default false
    */
    hasBorder?: boolean;
    /**
    * Elements to be displayed at the left position of the component.
    */
    slotLeft?: JSX.Element;
    /**
    * Elements to be displayed at the right position of the component.
    */
    slotRight?: JSX.Element;
    /**
    * Specifies the alignment of the left slot.
    */
    slotLeftAlign?: CSSProperties['alignSelf'];
    /**
    * Specifies the alignment of the right slot.
    */
    slotRightAlign?: CSSProperties['alignSelf'];
    /**
    * Specifies the on click handler when clicking on the sheet header. Mostly used to collapse the whole sheet body and used together with the slot right prop.
    */
    onClick?: MouseEventHandler;
}
/**
 The `SheetHeader` component can be used inside a `Sheet` component to add more structure with title and additional props for icons and interactivity, it is used together with the `SheetBody`.

  ### Import

  ```
  import SheetHeader from '@impargo/components/Sheet/SheetHeader'
  ```
*/
export declare const SheetHeader: FC<SheetHeaderProps>;
export default SheetHeader;
//# sourceMappingURL=SheetHeader.d.ts.map