import { CSSProperties, FC, ReactNode } from 'react';
export type SheetVariant = 'xlarge' | 'large' | 'medium' | 'small';
export type Shadow = 'small' | 'medium' | 'large' | 'none';
export interface SheetProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
    * Class name assigned to the component. Should be use sparingly.
    */
    className?: string;
    /**
    * Elements to be rendered inside the component.
    */
    children: ReactNode;
    /**
    * Specifies the different variants.
    */
    variant?: SheetVariant;
    /**
    * Sets background color for the sheet.
    * @default colorSurfaceHc
    */
    bgColor?: CSSProperties['backgroundColor'];
    /**
    * Sets the width of the sheet.
    * @default auto
    */
    width?: CSSProperties['width'];
    /**
    * Sets the height of the sheet.
    * @default auto
    */
    height?: CSSProperties['height'];
    /**
    * Sets a shadow for the sheet.
    * @default none
    */
    shadow?: Shadow;
}
/**
 The `Sheet` component is used to display similar information together. It can be used inside other `Sheet`s components.

  ### Import

  ```
  import Sheet from '@impargo/components/Sheet'
  ```
*/
export declare const Sheet: FC<SheetProps>;
export default Sheet;
//# sourceMappingURL=index.d.ts.map