import { OnClickCallback } from '@impargo/components/Button';
import { CSSProperties, FC, ReactNode } from 'react';
export type StateSize = 'small' | 'large';
export type StateVariant = 'empty' | 'success';
export interface StateCTA {
    label: string;
    onClick: OnClickCallback;
    slotLeft?: JSX.Element;
    slotRight?: JSX.Element;
    dataTestid?: string;
    disabled?: boolean;
    tooltip?: string;
}
export interface StateProps {
    /**
    * Class name assigned to the component. Should be use sparingly.
    */
    className?: string;
    /**
    * Specifies which variant to show, either empty variant or a success.
    */
    variant?: StateVariant;
    /**
     * Title of the state component.
     */
    title?: string | ReactNode;
    /**
     * Supplemental text for additional context.
     */
    description?: string | ReactNode;
    /**
    * Specifies the different sizes.
    */
    size?: StateSize;
    /**
    * Sets the width of the state component.
    * @default 424px
    */
    width?: CSSProperties['width'];
    /**
    * Main component cta that contains the most relevant or desired action. Only available in with the `large` size.
    */
    mainCTA?: StateCTA;
    /**
    * First cta. Used to direct users to a different page of the application or perform a relevant action.
    */
    cta1?: StateCTA;
    /**
    * Second cta. Used to direct users to a different page of the application or perform a relevant action. Only available in a success variant.
    */
    cta2?: StateCTA;
    /**
    * Third cta. Used to direct users to a different page of the application or perform a relevant action. Only available in a success variant.
    */
    cta3?: StateCTA;
    /**
     * Icon to display in the component.
     * The icon library used is the FontAwesome icon library along with the `FontAwesomeIcon` component for React.
     */
    icon?: JSX.Element;
}
/**
 The `State` component is used to display either the successful result of an action (`variant="success") or no results in data view (`variant="empty"`).

  ### Import

  ```
  import State from '@impargo/components/State'
  ```
*/
export declare const State: FC<StateProps>;
export default State;
//# sourceMappingURL=index.d.ts.map