import { SerializedStyles } from '@emotion/react';
import { Column, ColumnDef, SortingState } from '@tanstack/react-table';
import { Dispatch, SetStateAction } from 'react';
import { ThemeType } from '../Themes';
import { ColumnType, RowSelection, Sorting } from './types';
interface GetColumnsOptions<T extends {}> {
    keys: (ColumnType<T> | string)[];
    customRenderer?: Record<string, any>;
    customHeaderRenderer?: Record<string, any>;
    selectable?: boolean;
    loading?: boolean;
    showRowBadge?: (data: T) => boolean;
    selectAllItems: () => void;
    unSelectAllItems: () => void;
    isSomeRowsSelected: boolean;
    isAllRowsSelected: boolean;
}
export declare function getRowId<T extends {
    id?: string;
    _id?: string;
}>(originalRow: T, index: number): string;
export declare function getColumns<T extends object>({ keys, customRenderer, customHeaderRenderer, selectable, loading, showRowBadge, selectAllItems, unSelectAllItems, isSomeRowsSelected, isAllRowsSelected, }: GetColumnsOptions<T>): ColumnDef<T>[];
export declare function tableCellMixin<T extends object>(theme: ThemeType, column?: ColumnDef<T>): SerializedStyles;
export declare function columnPinningMixinLeft(theme: ThemeType, isLastLeftPinnedColumn: boolean, left: number, zIndex: number): SerializedStyles;
export declare function columnPinningMixinRight(theme: ThemeType, isFirstRightPinnedColumn: boolean, right: number, zIndex: number): SerializedStyles;
export declare function columnPinningMixin<T extends object>(theme: ThemeType, column: Column<T>, zIndex?: number): SerializedStyles | null;
export declare const transformSortingToSortingState: (sortingKey?: Sorting) => SortingState;
/**
 *
 * @param data Data which we need to get which rows aren't selected
 * @param rowSelection Current row selection
 * @returns Filtered data not in current row selection
 */
export declare function getRowsNotSelected<T extends object>(data: T[], rowSelection: RowSelection): T[];
/**
 *
 * @param rowsToBeAdded Rows to be added to row selection to be selected
 * @param rowSelection Current row selection
 * @returns New row selection after adding new rows
 */
export declare function addRowsToRowSelection<T extends object>(rowsToBeAdded: T[], rowSelection: RowSelection): RowSelection;
/**
 *
 * @param rowsIdsToBeRemoved Rows Ids to be removed from current selection
 * @param rowSelection Current row selection
 * @returns New row selection after removing rows
 */
export declare function removeRowsFromRowSelection(rowsIdsToBeRemoved: string[], rowSelection: RowSelection): RowSelection;
/**
 *
 * @param selectedRows The objects passed to the batch actions
 * @param rowSelection The rows currently selected
 * @returns The objects to be passed after removing rows not currently selected
 */
export declare function removeSelectedRows<T extends object>(selectedRows: T[], data: T[]): T[];
export declare function useStateOrProps<T>(defaultValue: T, valueFromProps?: T, setValueFomProps?: Dispatch<SetStateAction<T>>): [T, Dispatch<SetStateAction<T>>];
export {};
//# sourceMappingURL=helpers.d.ts.map