import { BuiltInSortingFn, SortingFn } from '@tanstack/table-core';
import { CSSProperties } from 'react';
export type ColumnType<RowType extends {}> = {
    name: string;
    accessor?: string | ((row: RowType) => string | JSX.Element);
    width?: number;
    maxWidth?: number;
    minWidth?: number;
    /**
     * Allows elements to visibily overflow from the cells. Useful for tables that contain dropdowns
     */
    allowCellOverflow?: boolean;
    /**
     * Clicks on columns/cells with this prop passed as true will not trigger row expansion and onPressRow
     */
    ignoreClickEvents?: boolean;
    /**
     * Aligns text inside the column
     */
    align?: CSSProperties['textAlign'];
    /**
     * A function to sort the column with, or one of the default sorting types.
     */
    sortType?: SortingFn<RowType> | BuiltInSortingFn;
    /**
     * Disables sorting by this column. Only relevant if the table is sortable. Defaults to false.
     */
    disableSortBy?: boolean;
};
export type RenderFunction<RowType> = (row: RowType) => string | JSX.Element | null;
export type Sorting = {
    [column: string]: 1 | -1;
};
export type RowSelection = {
    [key: string]: boolean;
};
//# sourceMappingURL=types.d.ts.map