import { CSSProperties } from 'react';
import { TooltipAnchorProps } from '../Tooltip';
export interface TagProps extends TooltipAnchorProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Sets the variant of the component.
     * @default primary
     */
    variant?: 'primary' | 'secondary' | 'brand' | 'accent' | 'danger' | 'success' | 'warning';
    /**
     * Sets the size of the tag.
     * @default m
     */
    size?: 's' | 'm';
    /**
     * Sets onclick function and adds specific styling to the tag.
     */
    onClick?: (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => void;
    /**
     * Text displayed inside the tag component.
     */
    label: string | JSX.Element;
    /**
     * Specifies left slot of the tag.
     */
    slotLeft?: string | JSX.Element;
    /**
     * Specifies right slot of the tag.
     */
    slotRight?: string | JSX.Element;
    /**
     * Specifies the button of the tag placed to the right.
     * Accepts an element but `ActionButton` component is recommended to be used with small prop.
     */
    buttonRight?: JSX.Element;
    /**
     * Specifies the background color of the tag.
     */
    bgColor?: CSSProperties['backgroundColor'];
    /**
     * Specifies the text color of the tag.
     */
    color?: CSSProperties['color'];
    /**
     * Specifies the border of the tag, only when custom variant is set.
     */
    border?: CSSProperties['border'];
    /**
     * Sets the cursor of the component on hover.
     */
    cursor?: CSSProperties['cursor'];
    /**
     * Margin top
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Martin right
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Margin bottom
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Margin left
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Margin left and right
     */
    mx?: CSSProperties['marginLeft'];
    /**
     * Margin top and bottom
     */
    my?: CSSProperties['marginTop'];
    /**
     * max width for the base component
     */
    maxWidth?: CSSProperties['maxWidth'];
    /**
     * white space for the text component
     * @default nowrap
     */
    whiteSpace?: CSSProperties['whiteSpace'];
}
/**
 * The `Tag` component is used to categorize data, add attributes or add actions.
 */
export declare const Tag: import("@emotion/styled").StyledComponent<TagProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Tag;
//# sourceMappingURL=index.d.ts.map