import { FC } from 'react';
import { ITooltip as ReactTooltipProps } from 'react-tooltip';
export interface TooltipAnchorProps {
    /**
     * The tooltip id when using a custom (non-default) tooltip.
     * @default bottom
     */
    'data-tooltip-id'?: string;
    /**
     * Text to be shown inside the tooltip.
     */
    'data-tooltip-content'?: string;
    /**
     * The direction in which the tooltip will be displayed relative to the anchor.
     * @default bottom
     */
    'data-tooltip-place'?: 'top' | 'top-start' | 'top-end' | 'right' | 'right-start' | 'right-end' | 'bottom' | 'bottom-start' | 'bottom-end' | 'left' | 'left-start' | 'left-end';
    /**
     * Variant of the tooltip displayed.
     * The variant used is based on the context.
     * @default normal
     */
    'data-tooltip-variant'?: 'primary' | 'info' | 'normal';
}
export interface TooltipProps extends Omit<ReactTooltipProps, 'content' | 'variant'> {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Variant of the tooltip displayed.
     * The variant used is based on the context.
     * @default normal
     */
    variant?: 'primary' | 'info' | 'normal';
    /**
     * Content to be displayed inside of the tooltip. Used as a prop.
     */
    content?: string | JSX.Element;
    /**
     * Id passed to the tooltip.
     * It needs to be passed to the div on which the tooltip should be shown with `data-tooltip-id={id}`, and if needed `data-tooltip-place`.
     */
    id?: string;
}
/**
 * Tooltips display information text when users hover over, or tap an element. They display information identifying an element, or a description of its function.
 *
 * There are two ways to use tooltips:
 * - Use the default tooltips by rendering `DefaultTooltip` at the root of your application and then using `data-tooltip-content` on your different components to provide tooltips.
 * - Implement custom tooltips by using the Tooltip component in combination with `data-tooltip-id`. This is useful when creating more complex or interactive tooltips.
 *
 * The tooltip component is implemented under the hood using `react-tooltip`.
 * More information about the library and the props accepted by the component can be found [here](https://react-tooltip.com/docs/getting-started).
 *
  ### Import

  ```
  import Tooltip from '@impargo/components/Tooltip'
  ```
 */
export declare const Tooltip: FC<TooltipProps>;
/**
 * Enables the use of default tooltips in various components (Button, ActionButton, Tag, Text, etc).
 * Needs to be rendered only once at the root of your application.
 */
export declare const DefaultTooltip: () => import("@emotion/react/jsx-runtime").JSX.Element;
export default Tooltip;
//# sourceMappingURL=index.d.ts.map